Eckcouch MARY in Grau mit Schlaffunktion | Pharao24.de
Description: Hübsche Eckcouch MARY in Grau ✓ Mit Schlaffunktion & Federkern ✓ Bezug aus Microfaser ✓ Ca. 250 cm breit ✓ Super bequem ✓ Jetzt schnell online kaufen

- Kundenservice 02973 97 91 20
- Geprüfte Sicherheit
- Jahrelange Möbel-Online Erfahrung
- 2% Rabatt bei Vorkasse

Pharao24 – Möbel Online bestellen
Suche:
Kostenloser Versand
Geprüfte
Datensicherheit
0
0,00 €
zum Warenkorb
Menü

# Eckcouch mit Schlaffunktion und Federkern grau MARY

Weitere Angebote:

Ecksofas | Eckgarnituren

Sofaecke | Polsterecken

Lieferzeit:

ab Bestellung innerhalb von 15 - 20 Werktagen

Frage Empfehlen Merken Vergleichen

Details auf einen Blick

Material | Microfaser
BxHxT | 252x74x87cm
Bezugsstoff | Microfaser, 100% Polyester
Sitzhöhe | 42
Unterfeder. | Nosagunterfederung
Sonstiges | Auszugsmechanik auf Sitzhöhe

» Zur Artikel-Beschreibung
729,00 €
inkl. 19% MwSt.

*Ausführung

Loading...
Menge

Artikelnummer: 10001357

Produktdetails

  Details auf einen Blick

  Material | Microfaser
  BxHxT | 252x74x87cm
  Bezugsstoff | Microfaser, 100% Polyester
  Sitzhöhe | 42
  Unterfeder. | Nosagunterfederung
  Sonstiges | Auszugsmechanik auf Sitzhöhe

  - Tolles Sofa in Mittelgrau (Farbe fällt etwas dunkler aus als abgebildet) mit schwarzen Rückenkissen
  - Korpus aus Spanplatte und Sperrholz, Bezug aus Microfaser
  - Mit praktischer Schlaffunktion
  - Zerlegt, zum leichten Selbstaufbau (Montageanleitung liegt bei)
  - Sperrholzrahmen
  - Unterfederung mit Nosagfedern
  - Polsterung: Federkern
  - Korpusstoff: Microfaser grau, 100% Polyester
  - Höhe Armlehnen vom Sitz aus: 24 cm
  - Sitzhöhe in cm: 42
  - Sitztiefe in cm: 78
  - Lichtechtheit des Stoffes: 4
  - Kunststofffüße, Chromfarben
  - Rücken echt bezogen
  - Auszugsmechanik auf Sitzhöhe
  - Martindale (Scheuertouren bei Bezugsstoff!): 40.000 Touren
  - Große Rückenkissen: Microfaser braun, 100% Polyester
  - Liegefläche: 140 x 205 cm
  - Stellmaß: 252 x 178 cm
  - Lehnenhöhe: 63 cm
  - Martindale: 45.000 Scheuertouren
  - Varianten
  - 001: Schenkel Seite: Kurzer Schenkel links (Frontansicht), Kurzer Schenkel links (Frontansicht)
  - 002: Schenkel Seite: Kurzer Schenkel rechts (Frontansicht)
  Kundenvorteile bei Pharao24.de:

  Selbstverständlich haben Sie bei uns 2 Jahre gesetzliche Gewährleistung

  Mehr von Müllermöbel

  Produktbewertungen von Käufern:

  Belegnummer: Andreas H.

  Es ist ein prima Sofa für den Preis. Der Anbieter ist zuverlässig. Ich empfehle das Sofa gern weiter.

  Belegnummer: 41301408

  "Preis-/Leistung und Qualität in Ordnung."

Produktbeschreibung

  Eckcouch mit Schlaffunktion und Federkern grau MARY

  Dieses hochwertige Funktionssofa ist nach höchstem Produktionsstandard gefertigt, verarbeitet mit Sperrholzrahmen, langlebiger und robuster Abpolsterung der Sitzfläche durch Federkern. Dieses Sofa bietet Ihnen ideale Sitz- und Schlafmöglichkeiten. Der geräumige Bettkasten, die hochwertigen Bezugsstoffe sowie chromfarbene Kunststoffüße und die Liegefläche von 140 x 200 cm runden dieses Modell ab. Ob als Gästebett oder Sitzcouch - hier sitzen und liegen Sie richtig. Hinweis und Information für Sie: Bitte beachten Sie, dass es sich bei unserem Produkt um ein Qualitätsprodukt handelt, das nach höchsten Maßstäben und Ansprüchen gefertigt wird. Es ist bekannt und auch dankenderweise in den Medien publiziert worden, dass es viele Billigimporte aus Nicht-EU-Staaten am Markt gibt, die zu völlig überteuerten Verkaufspreisen angeboten und verkauft werden. Setzen Sie auf Qualität. Wir garantieren Qualität.

  Weitere tolle Alternativen finden Sie hier:

  ecksofa mit schlaffunktion microfaser

  eckcouch

  eckcouch mit schlaffunktion leder

Ratgeber
Zahlung & Lieferung
Sicher einkaufen

Hier finden Sie weitere, passende Produkte:

- Sitzecke braun mit Auszieh-Mechanismus JOSY
  649,00 €
- Sitzecke mit Schlaffunktion rot EVA
  649,00 €
- Eck-Wohnlandschaft blau mit Schlafmöglichkeit ALICIA
  649,00 €
- Ecksofa mit Schlaf-und Sitzgelegenheit anthrazit MAITE
  659,00 €

Hier finden Sie unsere alternativen Modelle:

- Ecksofa Moda mit Schlaffunktion
  879,00 €
- Eck-Schlafcouch mit Federkern braun JANE
  679,00 €
- Sitzecke mit Schlaffunktion rot EVA
  649,00 €
- Ecksofa mit Schlaf-und Sitzgelegenheit anthrazit MAITE
  659,00 €
- Eck-Sofa mit Schlaffunktion braun STELLA
  679,00 €